==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/GridColumnHideOptionsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GridColumnOptionsSimpleSectionBaseDescriptionMetadata } from "./GridColumnOptionsSimpleSectionBaseDescriptionMetadata";
import { GridColumnHideOptionsDescription } from "./GridColumnHideOptionsDescription";
/**
 * @hidden
 */
var GridColumnHideOptionsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(GridColumnHideOptionsDescriptionMetadata, _super);
    function GridColumnHideOptionsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    GridColumnHideOptionsDescriptionMetadata.b = function (a) {
        if (GridColumnHideOptionsDescriptionMetadata.a == null) {
            GridColumnHideOptionsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            GridColumnHideOptionsDescriptionMetadata.c(GridColumnHideOptionsDescriptionMetadata.a);
        }
        if (a.k(GridColumnHideOptionsDescriptionMetadata.a)) {
            return;
        }
        a.aa(GridColumnHideOptionsDescriptionMetadata.a);
    };
    GridColumnHideOptionsDescriptionMetadata.c = function (a) {
        GridColumnOptionsSimpleSectionBaseDescriptionMetadata.c(a);
    };
    GridColumnHideOptionsDescriptionMetadata.d = function (a) {
        GridColumnHideOptionsDescriptionMetadata.b(a);
        a.ac("GridColumnHideOptions", function () { return new GridColumnHideOptionsDescription(); });
        a.ab("GridColumnHideOptions", GridColumnHideOptionsDescriptionMetadata.a);
    };
    GridColumnHideOptionsDescriptionMetadata.$t = markType(GridColumnHideOptionsDescriptionMetadata, 'GridColumnHideOptionsDescriptionMetadata');
    GridColumnHideOptionsDescriptionMetadata.a = null;
    return GridColumnHideOptionsDescriptionMetadata;
}(Base));
export { GridColumnHideOptionsDescriptionMetadata };

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm5/lib/GridColumnHideOptionsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GridColumnOptionsSimpleSectionBaseDescriptionMetadata } from "./GridColumnOptionsSimpleSectionBaseDescriptionMetadata";
import { GridColumnHideOptionsDescription } from "./GridColumnHideOptionsDescription";
/**
 * @hidden
 */
var GridColumnHideOptionsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(GridColumnHideOptionsDescriptionMetadata, _super);
    function GridColumnHideOptionsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    GridColumnHideOptionsDescriptionMetadata.b = function (a) {
        if (GridColumnHideOptionsDescriptionMetadata.a == null) {
            GridColumnHideOptionsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            GridColumnHideOptionsDescriptionMetadata.c(GridColumnHideOptionsDescriptionMetadata.a);
        }
        if (a.k(GridColumnHideOptionsDescriptionMetadata.a)) {
            return;
        }
        a.ac(GridColumnHideOptionsDescriptionMetadata.a);
    };
    GridColumnHideOptionsDescriptionMetadata.c = function (a) {
        GridColumnOptionsSimpleSectionBaseDescriptionMetadata.c(a);
    };
    GridColumnHideOptionsDescriptionMetadata.d = function (a) {
        GridColumnHideOptionsDescriptionMetadata.b(a);
        a.ae("GridColumnHideOptions", function () { return new GridColumnHideOptionsDescription(); });
        a.ad("GridColumnHideOptions", GridColumnHideOptionsDescriptionMetadata.a);
    };
    GridColumnHideOptionsDescriptionMetadata.$t = markType(GridColumnHideOptionsDescriptionMetadata, 'GridColumnHideOptionsDescriptionMetadata');
    GridColumnHideOptionsDescriptionMetadata.a = null;
    return GridColumnHideOptionsDescriptionMetadata;
}(Base));
export { GridColumnHideOptionsDescriptionMetadata };
